function B = mel_bank(fs, m, NFFT)

% B = mel_bank(fs, m, NFFT)
% 
% Tato funkce vraci banku trojuhelnikovych filtru rovnomerne rozlozenych v
% melovske skale.
% 
% fs    - vzorkovaci kmitocet
% m     - pocet filtru v bance
% NFFT  - pocet vzorku modulove kmitoctove charakteristiky (defaultne:
%         fs/2)
% B     - matice filtru; kazdemu sloupci odpovida modulova kmitoctova
%         charakteristika jednoho filtru

if((nargin < 3) || isempty(NFFT))
    NFFT = fix(fs/2);
end

%% Vypocet strednich kmitoctu v melovske skale
wdt = fix(hz2mel(fix(fs/2))/(m+1));
bm = ((1:m)*wdt).';

%% Prepocet strednich kmitoctu na hertzovou skalu
b = mel2hz(bm);
b = fix([1; b; fs/2]);

%% Vypocet bank filtru
B = zeros(fix(fs/2),m); % Alokace pameti
f = 1:fix(fs/2); % Kmitoctova osa

for i = 1:size(B,2)
    B(b(i):b(i+1),i) = (f(b(i):b(i+1))-b(i))./(b(i+1)-b(i));
    B(b(i+1):b(i+2),i) = (f(b(i+1):b(i+2))-b(i+2))./(b(i+1)-b(i+2));
end

%% Zmena poctu vzorku
P = size(B,1)/gcd(size(B,1),NFFT);
Q = NFFT/gcd(size(B,1),NFFT);

B = resample(B,Q,P);