function c = mfcc(x, fs, winlen, winover, m, NFFT)

% c = mfcc(x, fs, winlen, winover, m, NFFT)
% 
% Tato funkce vraci melovske kepstralni koeficienty MFCC pro vstupni
% signal.
% 
% x         - vstupni signal ve sloupcovem vektoru
% fs        - vzorkovaci kmitocet
% winlen    - delka okna ve vzorcich nebo samotne okno
% winover   - delka prekryvu ve vzorcich
% m         - pocet filtru v bance (defaultne: 15)
% NFFT      - pocet vzorku FFT (defaultne: 4096)
% c         - vystupni matice koeficientu MFCC

%% Paths and variables
if((nargin < 5) || isempty(m))
    m = 15;
end
if((nargin < 6) || isempty(NFFT))
    NFFT = 4096;
end

%% Segmentace
X = segmentace(x, winlen, winover);

%% Modulove spektrum signalu
XX = abs(fft(X,NFFT));
XX = XX(1:fix(end/2),:);

%% Vypocet banky filtru
B = mel_bank(fs, m, size(XX,1));

%% Nasobeni a nasledna sumace prvku
c = (B')*XX;

%% Prirozeny logaritmus a DCT
c = dct(log(c));

%% Nahrazeni prvnich koeficientu energii
c(1,:) = log(sum(abs(X).^2));