function num = numbers_DTW(y, fs, winlen, winover, m, NFFT, spk_ID)

% num = numbers_DTW(y, fs, winlen, winover, m, NFFT, spk_ID)
% 
% Tato funkce rozpoznava cisla pomoci algoritmu DTW.
% 
% y         - vstupni signal ve sloupcovem vektoru
% fs        - vzorkovaci kmitocet
% winlen    - delka okna ve vzorcich nebo samotne okno
% winover   - delka prekryvu ve vzorcich
% m         - pocet filtru v bance (defaultne: 15)
% NFFT      - pocet vzorku FFT (defaultne: 4096)
% spk_ID    - kdyz je tato promenna definovana, klasifikator se natrenuje
%             novou databazi
% num       - vystupni klasifikovane cislo

%% Promenne
if((nargin < 5) || isempty(m))
    m = 15;
end
if((nargin < 6) || isempty(NFFT))
    NFFT = 4096;
end

%% Nacteni signalu a vypocet koeficientu MFCC
if((nargin == 7) || ~exist('numbers.mat','file'))
    X = cell(1,10);

    for i = 0:9
        [x, fs] = wavread(['wav\cislovky\' num2str(i) '\' ...
            num2str(spk_ID) '.wav']);
        x = x./max(abs(x));
        X{i+1} = mfcc(x, fs, winlen, winover, m, NFFT);
    end

    save('numbers.mat','X');
else
    load('numbers.mat');
end

%% Vypocet matice MFCC pro testovaci signal
Y = mfcc(y, fs, winlen, winover, m, NFFT);

%% Hledani nejblizsiho vzoru
dist = zeros(10,1);

for i = 1:size(dist,1)
    dist(i) = DTW(Y,X{i});
end

[tmp, pos] = min(dist);
num = pos-1;